local AddonName, NickAlert = ...
local FriendlyAddonName = "Nick Alert"


-- Config Panel Text Strings

local label = 1 -- variablename, type, text
local checkbox = 2 -- variablename, type, text
local slider = 3 -- variablename, type, text, min, max, step
local fontslider = 4 -- variablename, type, text, min, max, step
local radio = 5 -- variablename, type, text, buttoncount, buttontext1, buttontext2, ...

local K = {	"labelState",		label,		"Add On State:",
			"Enable", 			checkbox,	"Enable the Add On to function",
			"AutoAdd",			checkbox,	"Add your character names to the list automatically",
			"labelToast",		label,		"Toast Settings:",
			"Toasts",			checkbox,	"Alert you when people go online/offline (Must be checked for any toast alerts)",
			"ToastMode",		radio,		"Select which toasts to alert for below:", 	3,	"Online", "Offline", "Both",
			"TFriends",			checkbox,	"All Friends online/offline toasts(checked) or just marked",
			"TGuild",			checkbox,	"All Guild online/offline toasts(checked) or just marked",
			"TBNet",			checkbox,	"All Real-ID/Battle-Tag online/offline toasts(checked) or just marked",
			"labelScan",		label,		"Nick/Trigger scanning:",
			"Guild",			checkbox,	"Scan Guild channel",
			"Party",			checkbox,	"Scan Party channel",
			"Say",				checkbox,	"Scan Say channel",
			"BGs",				checkbox,	"Scan Battleground channel",
			"Raid",				checkbox,	"Scan Raid channel",
			"Yell",				checkbox,	"Scan Yell channel",
			"Emotes",			checkbox,	"Scan Emotes",
			"Chats",			checkbox,	"Scan Other channels",
			"labelWhisper",		label,		"Message Settings:",
			"AllWhispers",		checkbox,	"Alert for all received whispers",
			"AllFriends",		checkbox,	"Alert for whispers from friends",
			"AllGuild",			checkbox,	"Alert you on a whisper from a guildie",
			"AllBNet",			checkbox,	"Alert for all Battle-Net messages",
			"WhisperList",		checkbox,	"Alert you when specified people whisper you",
			"BNet",				checkbox,	"Alert you when specified Real ID / Battle Tag people msg you",
			"labelOutput",		label,		"Output Settings:",
			"ChatDebug",		checkbox,	"Print all matches to default chat log",
			"CustomMP3",		checkbox,	"Enable custom alert.mp3 sound",
			"CustomOGG",		checkbox,	"Enable custom alert.ogg sound",
			"Throttle",			checkbox,	"Enable alert throttle",
			"ThrottleTime",		slider,		"Amount of time to throttle over         ", 1, 60, 1,
			"ThrottleAmount",	slider,		"Max number of alerts in above time    ", 1, 60, 1,
			"FadeDelay",		slider,		"   Fade message frame text after X seconds", 1, 60, 1,
			"DisplayMode",		checkbox,	"Enable display of mode text in alert (ie Party, Guild, BNet)",
			"MSBT",				checkbox,	"Enable output to MSBT's notification frame",
			"Sound",			checkbox,	"Enable sound to notify you of an alert",
			"MF",				checkbox,	"Enables output to the moveable message frame",
			"MFWarn",			checkbox,	"Warn you when the message frame is unlocked for an extended time",
			"MFAutoScale",		checkbox,	"Message Frame Auto-scale. Un-check to use the slider below.",
			"MFScale",			slider,		"           Percent scale of the message frame (50 - 300)", 50, 300, 1,
			"FontSize",			fontslider,	"Font Size in message frame                   ", 7, 24, 1,
			"Log",				checkbox,	"Put all the alerts into the log window",
			"LogShow",			checkbox,	"Show the log as soon as you log in",
			"ScreenFlash",		checkbox,	"Flash the edges of the screen when you receive a message",
			"RaidIcons",		checkbox,	"Process {rt#} in messages to raid target graphic",
			"HideHandledToasts",checkbox,	"Hide toasts from WoW toast frame if Nick Alert handled them",
	}


-- Local text colors
local yel = "|cFFFFFF00"
local wht = "|cFFFFFFFF"
local blu = "|cFF00FFFF"
local red = "|cFFFF0000"
local grn = "|cFF00FF00"
local res = "|r"



-- Bill's Utils
local Wait = BillsUtils.Wait
local ChkBox = BillsUtils.ChkBox
local ChkBoxSave = BillsUtils.ChkBoxSave
local CheckClick = BillsUtils.CheckClick
local SliderSave = BillsUtils.SliderSave
local SliderMW = BillsUtils.SliderMW
local Slider = BillsUtils.Slider
local SliderEditBox = BillsUtils.SliderEditBox
local SJprint = BillsUtils.SJprint
local Radio = BillsUtils.Radio

BillsUtils.Locals[#BillsUtils.Locals +1] = function ()
	Wait = BillsUtils.Wait
	ChkBox = BillsUtils.ChkBox
	ChkBoxSave = BillsUtils.ChkBoxSave
	CheckClick = BillsUtils.CheckClick
	SliderSave = BillsUtils.SliderSave
	SliderMW = BillsUtils.SliderMW
	Slider = BillsUtils.Slider
	SliderEditBox = BillsUtils.SliderEditBox
	SJprint = BillsUtils.SJprint
	Radio = BillsUtils.Radio
end

-- General Settings / functions
local X = 16 -- standard Horizontal Spacing
local Y = 35 -- standard Vertical spacing 26
local TxtY = 13
local NAS -- NickAlert.Settings
local NAD -- NickAlert.Defaults
local NN -- NickAlert.NickNames
local CF -- NickAlert.ChatFilter
local WL -- NickAlert.WhisperList
local PerChar -- NickAlert.PerChar
local NAT -- NickAlert.ToastsList 
local Triggers --NickAlert.Triggers
local AF --NickAlert.AlertFilters

local HighestButton = 16

-- Color Changing Button stuff
local ButtonTextures = {
	RED = {
		up = "Interface\\Buttons\\UI-Panel-Button-Up",
		down = "Interface\\Buttons\\UI-Panel-Button-Down",
		highlight = "Interface\\Buttons\\UI-Panel-Button-Highlight",
	},
	GREEN = {
		up = "Interface\\AddOns\\NickAlert\\Green-Panel-Button-Up",
		down = "Interface\\AddOns\\NickAlert\\Green-Panel-Button-Down",
		highlight = "Interface\\AddOns\\NickAlert\\Green-Panel-Button-Highlight",
	},
}

local function GetSkin(self)
	return self.__skin
end

local function SetSkin(self, skin)
	if self.__skin == skin then return end
	self.__skin = skin

	if self:IsMouseOver() and IsMouseButtonDown() then
		local down = ButtonTextures[skin].down
		self.Left:SetTexture(down)
		self.Right:SetTexture(down)
		self.Middle:SetTexture(down)
	else
		local up = ButtonTextures[skin].up
		self.Left:SetTexture(up)
		self.Right:SetTexture(up)
		self.Middle:SetTexture(up)
	end

	self:SetHighlightTexture(ButtonTextures[skin].highlight, "ADD")
	self:GetHighlightTexture():SetTexCoord(0, 80/128, 0, 22/32)
end

local function OnMouseDown(self, button)
	local down = ButtonTextures[self.__skin].down
	self.Left:SetTexture(down)
	self.Right:SetTexture(down)
	self.Middle:SetTexture(down)
end

local function OnMouseUp(self, button)
	local up = ButtonTextures[self.__skin].up
	self.Left:SetTexture(up)
	self.Right:SetTexture(up)
	self.Middle:SetTexture(up)
end

local function NewButton(parent, skin, name)
	local button = CreateFrame("Button", name, parent or UIParent)
	button:SetSize(40, 22)

	local left = button:CreateTexture(nil, "BACKGROUND")
	left:SetPoint("TOPLEFT")
	left:SetPoint("BOTTOMLEFT")
	left:SetWidth(12)
	left:SetTexCoord(0, 12/128, 0, 22/32)
	button.Left = left

	local right = button:CreateTexture(nil, "BACKGROUND")
	right:SetPoint("TOPRIGHT")
	right:SetPoint("BOTTOMRIGHT")
	right:SetWidth(12)
	right:SetTexCoord(68/128, 80/128, 0, 22/32)
	button.Right = right

	local middle = button:CreateTexture(nil, "BACKGROUND")
	middle:SetPoint("TOPLEFT", left, "TOPRIGHT")
	middle:SetPoint("BOTTOMRIGHT", right, "BOTTOMLEFT")
	middle:SetTexCoord(12/128, 68/128, 0, 22/32)
	button.Middle = middle

	local text = button:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	text:SetAllPoints(true)
	text:SetJustifyH("CENTER")
	text:SetJustifyV("CENTER")
	button:SetFontString(text)
	button:SetNormalFontObject("GameFontNormal")
	button:SetHighlightFontObject("GameFontHighlight")	

	button:SetScript("OnMouseDown", OnMouseDown)
	button:SetScript("OnMouseUp", OnMouseUp)
	button:SetScript("OnShow", OnMouseUp)

	button.GetSkin = GetSkin
	button.SetSkin = SetSkin

	SetSkin(button, skin or "RED")

	return button
end

NickAlert.ConfigInit = function()
	NAS = NickAlert.Settings
	NAD = NickAlert.Defaults
	NN = NickAlert.NickNames
	CF = NickAlert.ChatFilter
	WL = NickAlert.WhisperList
	PerChar = NickAlert.PerChar
	NAT = NickAlert.ToastsList
	Triggers = NickAlert.Triggers
	AF = NickAlert.AlertFilters
end

NickAlert.Checkclick = function()
	PlaySound( "GAMEGENERICBUTTONPRESS" )
end

local Label = function( last, parent, text)
	local SubText = parent:CreateFontString( nil, "ARTWORK", "GameFontNormal" )
	if last == parent then
		SubText:SetPoint( "TOPLEFT", last, "TOPLEFT", 10, 0 )
	else
		SubText:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -10 )
	end
	--SubText2:SetPoint( "RIGHT", -32, 0 )
	SubText:SetHeight( 32 )
	SubText:SetJustifyH( "LEFT" )
	SubText:SetJustifyV( "MIDDLE" )
	SubText:SetText( text )
	return SubText
end

--Panel
NickAlert.panel = CreateFrame( "Frame", "NAlertConfig", UIParent )
NickAlert.panel2 = CreateFrame( "Frame", "NAlertConfig2", NickAlert.panel )
local me = NickAlert.panel
local me2 = NickAlert.panel2
me:SetScript("OnLoad", function()
	NickAlert.init()
end)


me.name = "Nick Alert"
me2:SetSize(380, 475)
me2:SetPoint("BOTTOMRIGHT", me, "BOTTOMRIGHT")

-- Pane title
	local Title = me:CreateFontString( nil, "ARTWORK", "GameFontNormalLarge" )
	Title:SetPoint( "TOPLEFT", 16, -16 )
	Title:SetText( "Nick Alert" )
	local SubText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" )
	SubText:SetPoint( "TOPLEFT", Title, "BOTTOMLEFT", 0, -8 )
	SubText:SetPoint( "RIGHT", -32, 0 )
	SubText:SetHeight( 32 )
	SubText:SetJustifyH( "LEFT" )
	SubText:SetJustifyV( "TOP" )
	SubText:SetText( "Change how Nick Alert behaves by setting the options below" )

-- Scroll Frame
	me.ScrollFrame = CreateFrame("ScrollFrame", "NAlertConfigScrollFrame", me, "UIPanelScrollFrameTemplate")
	me.ScrollFrame:SetScrollChild(me2)
	me.ScrollFrame:SetPoint("TOPRIGHT", me ,"TOPRIGHT", -30,- 64)
	me.ScrollFrame:SetPoint("BOTTOMRIGHT", me ,"BOTTOMRIGHT", -30, 10)
	me.ScrollFrame:SetPoint("BOTTOMLEFT", me ,"BOTTOMLEFT", 30, 10)
	
	local FontSizeDemo
	local SliderFontSize = function(self, delta)
		local min,max = self:GetMinMaxValues()
		local step = self:GetValueStep()
		local value = self:GetValue()
	
		if delta < 0 then 
			value = value - step
		elseif delta > 0 then
			value = (value + step)
		end
		if value < min then
			value = min
		elseif value > max then
			value = max
		end
		self:SetValue( value )
		FontSizeDemo:SetFont( STANDARD_TEXT_FONT, value )
		FontSizeDemo:SetText( "Font Size Demo "..tostring(value) )
	end
	
	
	local commandCount = 0
	local last = me2
	local Type
	
	while K[commandCount + 1] do
		commandCount = commandCount + 1
		Type = K[commandCount + 1]
		if Type == label then
			me[K[commandCount]] = Label( last, me2, K[commandCount + 2])
			last = me[K[commandCount]]
			commandCount = commandCount + 2
			
		elseif Type == checkbox then
			me[K[commandCount]] = ChkBox( last , "NickAlertCfg", K[commandCount], me2, CheckClick, K[commandCount + 2] )
			last = me[K[commandCount]]
			commandCount = commandCount + 2
			
		elseif Type == slider then
			me[K[commandCount]] = Slider( last , "NickAlertCfg", K[commandCount], me2 , SliderMW , K[commandCount + 2], K[commandCount + 3],K[commandCount + 4], K[commandCount + 5] )
			last = me[K[commandCount]]
			last.Val = SliderEditBox( last , "NickAlertCfg", K[commandCount], me2 )
			commandCount = commandCount + 5
			
		elseif Type == fontslider then
			me[K[commandCount]] = Slider( last , "NickAlertCfg", K[commandCount], me2 , SliderFontSize , K[commandCount + 2], K[commandCount + 3],K[commandCount + 4], K[commandCount + 5]  )
			last = me[K[commandCount]]
			commandCount = commandCount + 5
			last:SetObeyStepOnDrag(true)
			last:SetScript( "OnValueChanged", function( self, value )
				PlaySound( "GAMEGENERICBUTTONPRESS" )
				local val = self:GetValue()
				self.Val:SetNumber( val )
				FontSizeDemo:SetFont( STANDARD_TEXT_FONT, val )
				FontSizeDemo:SetText( "Font Size Demo "..tostring( val ) )
				PlaySound( "GAMEGENERICBUTTONPRESS" )
			end)
			last.Val = SliderEditBox( me[K[commandCount]] , "NickAlertCfg", K[commandCount], me2 )
			
			FontSizeDemo = me2:CreateFontString( "NalertFontSizeDemo", "ARTWORK") --, "GameFontHighlightSmall" )
			FontSizeDemo:SetFont( STANDARD_TEXT_FONT, 10 )
			FontSizeDemo:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -0 )
			FontSizeDemo:SetPoint( "RIGHT", -32, 0 )
			FontSizeDemo:SetHeight( 32 )
			FontSizeDemo:SetJustifyH( "LEFT" )
			FontSizeDemo:SetJustifyV( "CENTER" )
			FontSizeDemo:SetText( "Font Size Demo" )

			last = FontSizeDemo
		elseif Type == radio then
		--	BU.Radio = function( Last, Prefix, Name, Parent, TextOrTable, TextName, ButtonTextTable )
			local ButtonText = {}
			for x = 1, K[commandCount + 3] do
				ButtonText[x] = K[commandCount + 3 + x]
			end
			me[K[commandCount]] = Radio( last, "NickAlertCfg", K[commandCount], me2, K[commandCount + 2], nil, K[commandCount + 3], ButtonText )
			last = me[K[commandCount]][1]
			commandCount = commandCount + 3 + K[commandCount + 3]
		end
	end

local MFScaleValue
-- Special Case Script Handlers
me.MFScale:HookScript("OnEnter", function(self)
	MFScaleValue = me.MFScale:GetValue()
end)

me.MFScale:HookScript("OnLeave", function(self)
	if me.MFScale:GetValue() ~= MFScaleValue then
		me.MFAutoScale:SetChecked(false)
	end
end)

me.MFScale.Val:HookScript("OnEnter", function(self)
	MFScaleValue = me.MFScale:GetValue()
end)

me.MFScale.Val:HookScript("OnLeave", function(self)
	if me.MFScale:GetValue() ~= MFScaleValue then
		me.MFAutoScale:SetChecked(false)
	end
end)



-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- X  Init / Reset the config panel to match current settings                                                     X
-- XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
--


NickAlert.Init = function(...)
	local count = 0
	local mode
	while K[count + 1] do
		count = count + 1
		mode = K[count + 1]
		if mode == checkbox then
			me[K[count]]:SetChecked(NAS[K[count]])
			count = count + 2
		elseif mode == slider or mode == fontslider then
			me[K[count]]:SetValue( NAS[K[count]])
			me[K[count]].Val:SetCursorPosition( 0 )
			me[K[count]].Val:SetNumber( NAS[K[count]] )
			count = count + 5
		elseif mode == radio then
			for x = 1, K[count + 3] do
				me[K[count]][x]:SetChecked(  NAS[K[count]] == K[count + 3 + x] )
			end
			count = count + 3 + K[count + 3]
		end
	end
end

-- Reset config panel and settings to DEFAULT
NickAlert.Reset = function(...)
	for index, value in pairs( NAD) do
		NAS[index] = value
	end
	
	NickAlert.Init()
end



me.refresh = function(self)
	NickAlert.Init()
end

me.default = function (self)
	NickAlert.Reset()
end

me.cancel = function (self)
	NickAlert.Init()
end


-- Save settings from config panel
me.okay = function(self)
	local count = 0
	while K[count + 1] do
		count = count + 1
		if K[count + 1] == checkbox then
			ChkBoxSave( me, K[count] , NAS)
			count = count + 2
		elseif K[count + 1] == slider or K[count + 1] == fontslider then
			SliderSave( me, K[count], NAS)
			count = count + 5
		elseif K[count + 1] == radio then
			for x = 1, K[count + 3] do
				if me[K[count]][x]:GetChecked() then
					if NAS[K[count]] ~= K[count + 3 + x] then
						NAS[K[count]] = K[count + 3 + x]
					end
				end
			end
			count = count + 3 + K[count + 3]
		end
	end
		
	NickAlert.SettingsUpdate()
	NickAlert.EventManager()
end

-- Register the config panel
InterfaceOptions_AddCategory( me )

-- ****************************************************************************
-- * List Manager Child Panel                                                 *
-- ****************************************************************************

local selectedGuild = GetGuildInfo("player")
local SliderFrame1
local SliderFrame2

StaticPopupDialogs["NICKALERT_DELETEGUILD"] = {
	text = "Do you want to delete the guild entry %s ?",
	button1 = "Yes",
	button2 = "No",
	OnAccept = function()
		NAT[selectedGuild] = nil
		selectedGuild = GetGuildInfo("player")
		NickAlert.ListDisplayUpdate()
	end,
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/ 
}

StaticPopupDialogs["NICKALERT_CANNOTDELETEGUILD"] = {
	text = "You cannot delete the guild you are currently in.",
	button1 = "OK",
	timeout = 0,
	whileDead = true,
	hideOnEscape = true,
	preferredIndex = 3,  -- avoid some UI taint, see http://www.wowace.com/announcements/how-to-avoid-some-ui-taint/ 
}

--Panel
NickAlert.panel3 = CreateFrame( "Frame", "NAlertConfig3", UIParent )
local me = NickAlert.panel3

me.name = "List Manager"
me.parent = NickAlert.panel.name

me.ListButtons = {}

-- Pane title
local Title = me:CreateFontString( nil, "ARTWORK", "GameFontNormalLarge" )
Title:SetPoint( "TOPLEFT", 16, -16 )
Title:SetText( "Nick Names" )
local SubText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
SubText:SetPoint( "TOPLEFT", Title, "BOTTOMLEFT", 0, -8 )
SubText:SetPoint( "RIGHT", -32, 0 )
SubText:SetHeight( 32 )
SubText:SetJustifyH( "LEFT" )
SubText:SetJustifyV( "TOP" )
SubText:SetText( "Manage your alert lists here"  )
	
local last = me
local width = _G["InterfaceOptionsFramePanelContainer"]:GetWidth() / 3 

me.SelectButton = {}
local selectedTab = 1
local SelectButtonWidth = _G["InterfaceOptionsFramePanelContainer"]:GetWidth() / 5
local SelectedMultiplier = 1.5 -- this is how much larger the selected mode is

local K = { ["Nicknames"] = 1,			[1] = "NickNames",			[101] = "NickList",
			["Triggers"] = 2,			[2] = "Triggers",			[102] = "Triggers",
			["Alert Filters"] = 3,		[3] = "Alert Filters",		[103] = "AlertFilters",
			["Chan Filters"] = 4,		[4] = "Chan Filters",		[104] = "Filter",
			["Whispers"] = 5,			[5] = "Whispers",			[105] = "WhisperList",
			["Battle Net"] = 6,			[6] = "Battle Net",
			["Friend Toasts"] = 7,		[7] = "Friend Toasts",
			["Guild Toasts"] = 8,		[8] = "Guild Toasts",
			["Battle Net Toasts"] = 9,	[9] = "Battle Net Toasts",
			}
			


			
me.SelectButtonUpdate = function()
	for x = 1, #K do
		if selectedTab == x then
			me.SelectButton[x]:SetSize( SelectButtonWidth * SelectedMultiplier , 20)
			me.SelectButton[x]:SetButtonState("PUSHED")
			me.SelectButton[x]:SetSkin("GREEN")
		else
			me.SelectButton[x]:SetSize( SelectButtonWidth , 20)
			me.SelectButton[x]:SetButtonState("NORMAL")
			me.SelectButton[x]:SetSkin("RED")
		end
	end
	me.slider:SetValue(0)
	me.slider2:SetValue(0)
	NickAlert.ListDisplayUpdate()
end

for x = 1, #K do
	me.SelectButton[x] = NewButton( me, "RED")
	if x == 1 then
		me.SelectButton[x]:SetPoint("TOPLEFT", last, "TOPLEFT", 20, -60 )
		last = me.SelectButton[x]
	elseif (x - 1) % 4  == 0 then
		me.SelectButton[x]:SetPoint("TOPLEFT", me.SelectButton[x - 4], "BOTTOMLEFT" )
		last = me.SelectButton[x]
	else
		me.SelectButton[x]:SetPoint("TOPLEFT", me.SelectButton[x-1], "TOPRIGHT" )
	end
	if selectedTab == x then
		me.SelectButton[x]:SetSize( SelectButtonWidth * SelectedMultiplier , 20)
		me.SelectButton[x]:SetButtonState("PUSHED")
		me.SelectButton[x]:SetSkin("GREEN")
	else
		me.SelectButton[x]:SetSize( SelectButtonWidth , 20)
		me.SelectButton[x]:SetButtonState("NORMAL")
		me.SelectButton[x]:SetSkin("RED")
	end
	me.SelectButton[x]:SetText( K[x] )
	me.SelectButton[x].count = x
	me.SelectButton[x]:SetScript("OnClick", function(self, button, down)
		if (button ~= "LeftButton") then
			return
		end
		PlaySound( "GAMEGENERICBUTTONPRESS" )
		if selectedTab ~= self.count and selectedTab <= 4 then
			me.EBox:SetText("")
		end
		selectedTab = self.count
		me.SelectButtonUpdate()
		return
	end)
	
end

local ButtonSubText = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
ButtonSubText:SetPoint( "TOPLEFT", last, "BOTTOMLEFT", 0, -8 )
ButtonSubText:SetPoint( "RIGHT", -32, 0 )
ButtonSubText:SetHeight( 32 )
ButtonSubText:SetJustifyH( "LEFT" )
ButtonSubText:SetJustifyV( "TOP" )
ButtonSubText:SetText( "Manage your alert lists here"  )

NickAlert.BNetToggle = function( ID )
	local _, _, _, _, _, _, _, _, _, _, _, _, noteText, _, _ = BNGetFriendInfoByID( ID )
	if selectedTab == K["Battle Net"] then -- BNet Msg
		key = "NAlert"
	else -- BNet Toast
		key = "NAToast"
	end
	
	local marked, markedEnd
	
	if not( noteText ) then
		marked = false
	else
		marked, markedEnd = string.find( noteText, key ) 
	end
	
	if marked then -- remove the mark
		local y = string.len(noteText)
		if marked == 1 and markedEnd == y then
			noteText = ""
		elseif markedEnd == y then
			noteText = string.sub(noteText, 1, marked - 1)
		elseif marked == 1 then
			noteText = string.sub(noteText, markedEnd + 1 )
		else
			noteText = string.sub(noteText, 1, marked-1)..string.sub(noteText, markedEnd +1)
		end
	else
		if noteText == nil or noteText == "" then
			noteText = key
		else
			noteText = noteText.." "..key
		end
	end
	noteText = string.trim(noteText)
	BNSetFriendNote( ID, noteText)
	return
end

NickAlert.ListToggle = function( list, value )
	local Table
	if list == "FToasts" then
		Table = PerChar.Toasts
	elseif list == "GToasts" then
		Table = NAT[selectedGuild]
	else
		return
	end
	
	if Table[value] then
		if list == "FToasts" then
			Table[value] = nil
		else
			Table[value] = false
		end
	else
		Table[value] = true
	end
	return
end

NickAlert.ListDisplayUpdate = function()
	local Table
	if selectedTab == K["Nicknames"] then
		Table = NN
		ButtonSubText:SetText( "Add / Remove nicknames to scan for here"  )
		me.EBox.Text:SetText( "Enter a nickname or click a button above (ignores case and matches from start of each word)" )
	elseif selectedTab == K["Triggers"] then
		Table = Triggers
		ButtonSubText:SetText( "Add / Remove triggers to scan for here"  )
		me.EBox.Text:SetText( "Enter a trigger or click a button above (Exact case match anywhere in message)" )
	elseif selectedTab == K["Chan Filters"] then
		Table = CF
		ButtonSubText:SetText( "These are the /# channels to watch \nChannels you are watching / Channels you are currently in"  )
		me.EBox.Text:SetText( "Enter a channel name or click a button above" )
	elseif selectedTab == K["Whispers"] then
		Table = WL
		ButtonSubText:SetText( "The addon will alert you if any of these people whisper you"  )
		me.EBox.Text:SetText( "Enter a nickname or click a button above" )
	elseif selectedTab == K["Friend Toasts"] then
		local FriendCount = GetNumFriends()
		if not(PerChar.Toasts) then
			PerChar.Toasts = {}
		end
		Table = {}
		for x = 1, FriendCount do
			Table[x] = (GetFriendInfo( x ))
		end
		table.sort(Table)
		ButtonSubText:SetText( "A list of friends that you can get toasts for \nClick the person's name to toggle. GREEN marked will alert you"  )
	elseif selectedTab == K["Guild Toasts"] then
		Table = {}
		for index, _ in pairs(NAT) do
			if index then
				Table[#Table +1] = index
			end
		end
		table.sort(Table)
		ButtonSubText:SetText( "These are the guilds you are/were in on this server / people in that guild"  )
	elseif selectedTab == K["Battle Net"] or selectedTab == K["Battle Net Toasts"] then
		Table = {}
		local FriendCount = BNGetNumFriends()
		for x = 1, FriendCount do
			Table[x] = {}
			Table[x].presenceID, Table[x].fullName, _, _, _, _, _, _, _, _, _, _, Table[x].noteText, _, _ = BNGetFriendInfo( x )
		end
		if selectedTab == K["Battle Net"] then
			ButtonSubText:SetText( "A list of Real IDs and Battle Tags than can alert you if they message you\nClick the person's name to toggle. GREEN will alert you"  )
		else -- K["Battle Net Toasts"]
			ButtonSubText:SetText( "A list of Real IDs and Battle Tags than can alert you if they log on/off \nClick the person's name to toggle. Green marked will alert you"  )
		end
	elseif selectedTab == K["Alert Filters"] then
		Table = AF
		ButtonSubText:SetText( "Add / Remove filters to override triggered alerts (like to prevent an addon from triggering an alert)"  )
		me.EBox.Text:SetText( "Enter a filter or click a button above (case sensitive and matches anywhere in message" )
	end
		
	local maxcount = #Table
	local slider = me.slider:GetValue()
		
	for x = 1 , HighestButton do
		if x + slider > maxcount then
			me.ListButtons[x]:SetText( " " )
			me.ListButtons[x].val = ""
			me.ListButtons[x]:SetSkin("RED")
		else
			if
			selectedTab == K["Nicknames"] or
			selectedTab == K["Triggers"] or
			selectedTab == K["Chan Filters"] or
			selectedTab == K["Whispers"] or
			selectedTab == K["Alert Filters"] then
				me.ListButtons[x]:SetSkin("RED")
				me.ListButtons[x]:SetText( Table[x + slider] )
				me.ListButtons[x].val = Table[x + slider]
			elseif selectedTab == K["Friend Toasts"] then
				if PerChar.Toasts[Table[x + slider]] then
					me.ListButtons[x]:SetSkin( "GREEN" )
				else
					me.ListButtons[x]:SetSkin( "RED" )
				end
				me.ListButtons[x]:SetText( Table[x + slider] )
				me.ListButtons[x].val = Table[x + slider]
			elseif selectedTab == K["Guild Toasts"] then
				if not( selectedGuild ) then
					selectedGuild = (GetGuildInfo("player"))
				end
				if Table[x + slider] == selectedGuild then
					me.ListButtons[x]:SetSkin( "GREEN" )
				else
					me.ListButtons[x]:SetSkin( "RED" )
				end
				me.ListButtons[x]:SetText( Table[x + slider] )
				me.ListButtons[x].val = Table[x + slider]
			elseif selectedTab == K["Battle Net"] or selectedTab == K["Battle Net Toasts"] then
				local AlertText = "NAlert"
				if selectedTab == K["Battle Net Toasts"] then
					AlertText = "NAToast"
				end
					
				if Table[x + slider].noteText and string.find( Table[x + slider].noteText, AlertText) then
					me.ListButtons[x]:SetSkin( "GREEN" )
				else
					me.ListButtons[x]:SetSkin( "RED" )
				end
				me.ListButtons[x]:SetText( Table[x + slider].fullName )
				me.ListButtons[x].val = Table[x + slider].presenceID
			end
		end
	end
	me.slider:SetMinMaxValues( 0, (#Table > HighestButton and #Table - HighestButton or 1 ))
	if #Table <= HighestButton then
		me.slider:SetValue(0)
		me.slider:Disable(true)
	else
		me.slider:Enable(true)
	end
	
	-- ***************************************************************************
	-- * Chan List Buttons
	if selectedTab == K["Chan Filters"] then
		SliderFrame2:EnableMouseWheel(1)
		local chanlist = { GetChannelList() }
		local chanmax = #chanlist / 2
		for x = 1, HighestButton do
			me.ListButtons2[x]:SetSkin("RED")
			if x > chanmax then
				me.ListButtons2[x]:SetText(" ")
				me.ListButtons2[x].val = ""
			else
				me.ListButtons2[x]:SetText(chanlist[x * 2])
				me.ListButtons2[x].val = chanlist[x * 2]
			end
			me.ListButtons2[x]:Show()
		end
	elseif selectedTab == K["Guild Toasts"] then
		SliderFrame2:EnableMouseWheel(1)
		if not(selectedGuild) then
			local temp = (GetGuildInfo("player"))
			if temp then
				selectedGuild = temp
			else
				local TempTable = {}
				for index, _ in pairs(NAT) do
					TempTable[#TempTable +1] = index
				end
				table.sort(TempTable)
				if TempTable[1] then
					selectedGuild = TempTable[1]
				else
					print(red.."Nick Alert:"..wht.." There are no guilds saved and you are not in a guild so the Guild Toasts tab cannot be selected.")
					NickAlert.panel3.SelectButton[1]:Click("LeftButton")
					return
				end
			end
		end
		if not(NAT[selectedGuild]) then
			NAT[selectedGuild] = {}
		end
		
		local GNum
		local GTable = {}
		local S2Val = me.slider2:GetValue()
		if selectedGuild == GetGuildInfo("player") then
			GNum = GetNumGuildMembers()
			for x = 1, GNum do
				GTable[x] = (GetGuildRosterInfo(x))
			end
		else
			for index, _ in pairs(NAT[selectedGuild]) do
				GTable[#GTable +1] = index
			end
			GNum = #GTable
		end
		table.sort(GTable)
		
		for x = 1, HighestButton do
			if x + S2Val > GNum then
				me.ListButtons2[x]:SetSkin("RED")
				me.ListButtons2[x]:SetText(" ")
				me.ListButtons2[x].val = ""
			else
				if NAT[selectedGuild][GTable[x + S2Val]] then
					me.ListButtons2[x]:SetSkin("GREEN")
				else
					me.ListButtons2[x]:SetSkin("RED")
				end
				me.ListButtons2[x]:SetText(GTable[x + S2Val])
				me.ListButtons2[x].val = (GTable[x + S2Val])
			end
			me.ListButtons2[x]:Show()
		end
	else
		SliderFrame2:EnableMouseWheel(nil)
		for x = 1, HighestButton do
			me.ListButtons2[x]:Hide()
		end
	end
	
	-- ***************************************************************************
	-- * Add / Delete Ebox buttons
	if
	selectedTab == K["Nicknames"] or
	selectedTab == K["Triggers"] or
	selectedTab == K["Chan Filters"] or
	selectedTab == K["Whispers"] or
	selectedTab == K["Alert Filters"] then
		me.AddButton:Show()
		me.AddButton:SetText("Add")
		me.DeleteButton:Show()
		me.EBox:Show()
		me.EBox.Text:Show()
	elseif selectedTab == K["Guild Toasts"] then
		me.AddButton:Show()
		me.AddButton:SetText("Delete Guild")
		me.DeleteButton:Hide()
		me.EBox:Hide()
		me.EBox.Text:Hide()
	else
		me.AddButton:Hide()
		me.DeleteButton:Hide()
		me.EBox:Hide()
		me.EBox.Text:Hide()
	end
	
	if selectedTab ~= K["Guild Toasts"] then
		me.slider2:Hide()
	else
		me.slider2:Show()
		local count = 0
		if selectedGuild == (GetGuildInfo("player")) then
			count = GetNumGuildMembers()
		else
			for _,_ in pairs(NAT[selectedGuild]) do
				count = count + 1
			end
		end
		me.slider2:SetMinMaxValues( 0, (count > HighestButton and count - HighestButton or 1) )
		if count < 11 then
			me.slider2:SetValue(0)
			me.slider2:Disable(true)
		else
			me.slider2:Enable(true)
		end
	end	
end


for x = 1, HighestButton do
	me.ListButtons[x] = NewButton( me, "RED")
	if x == 1 then
		me.ListButtons[x]:SetPoint("TOPLEFT", last, "TOPLEFT", 60, -60 )
	else
		me.ListButtons[x]:SetPoint("TOPLEFT", last, "BOTTOMLEFT" )
	end
	me.ListButtons[x]:SetSize( width , 20)
	me.ListButtons[x]:SetText( " " )
	me.ListButtons[x].val = ""
	me.ListButtons[x]:SetScript("OnClick", function(self, button, down)
		if (button ~= "LeftButton") then
			return
		end
		if self.val == "" then return end
		PlaySound( "GAMEGENERICBUTTONPRESS" )
		if
		selectedTab == K["Nicknames"] or
		selectedTab == K["Triggers"] or
		selectedTab == K["Chan Filters"] or
		selectedTab == K["Whispers"] or
		selectedTab == K["Alert Filters"] then
			me.EBox:SetText(self.val)
			return
		elseif selectedTab == K["Battle Net"] then
			NickAlert.BNetToggle( self.val )
		elseif selectedTab == K["Friend Toasts"] then
			NickAlert.ListToggle("FToasts", self.val)
		elseif selectedTab == K["Guild Toasts"] then
				selectedGuild = self.val
		elseif selectedTab == K["Battle Net Toasts"] then
			NickAlert.BNetToggle( self.val )
		end
		NickAlert.ListDisplayUpdate()
		return
	end)
	last = me.ListButtons[x]
end
me.slider = CreateFrame( "Slider", "NAlertNNListSlider", me, "OptionsSliderTemplate" )
me.slider:SetMinMaxValues( 0, 1 )
me.slider:SetOrientation("VERTICAL")
me.slider:SetPoint("TOPLEFT", me.ListButtons[1] ,"TOPRIGHT", 5 , 0)
me.slider:SetPoint("BOTTOMLEFT", me.ListButtons[HighestButton] ,"BOTTOMRIGHT", 5 , 0)
me.slider:SetValueStep( 1 )
me.slider:SetWidth( 16 )	
me.slider:SetScript( "OnValueChanged", function( self )
	NickAlert.ListDisplayUpdate()
end)
getglobal(me.slider:GetName() .. 'Low'):SetText( " " )
getglobal(me.slider:GetName() .. 'High'):SetText( " " )
me.slider:SetScript("OnMouseWheel", function(self, delta)
	local number = 0
	if selectedTab == K["Nicknames"] then
		number = #NN
	elseif selectedTab == K["Triggers"] then
		number = #Triggers
	elseif selectedTab == K["Chan Filters"] then
		number = #CF
	elseif selectedTab == K["Whispers"] then
		number = #WL
	elseif selectedTab == K["Friend Toasts"] then
		number = GetNumFriends()
	elseif selectedTab == K["Guild Toasts"] then
		for _,_ in pairs(NAT) do
			number = number + 1
		end
	elseif selectedTab == K["Battle Net"] or selectedTab == K["Battle Net Toasts"] then
		number = BNGetNumFriends()
	elseif selectedTab == K["Alert Filters"] then
		number = #AF
	end
	if number <= HighestButton then
		return
	end
	SliderMW(self, -delta)
end)
SliderFrame1 = CreateFrame( "Frame", "NAlertSliderFrame1", me )
SliderFrame1:SetPoint("TOPLEFT", me.ListButtons[1], "TOPLEFT", -10, 10)
SliderFrame1:SetPoint("BOTTOMRIGHT", me.slider, "BOTTOMRIGHT", 10, -10)
SliderFrame1:EnableMouseWheel(1)
SliderFrame1:SetScript("OnMouseWheel", function(self, delta)
	local number = 0
	if selectedTab == K["Nicknames"] then
		number = #NN
	elseif selectedTab == K["Triggers"] then
		number = #Triggers
	elseif selectedTab == K["Chan Filters"] then
		number = #CF
	elseif selectedTab == K["Whispers"] then
		number = #WL
	elseif selectedTab == K["Friend Toasts"] then
		number = GetNumFriends()
	elseif selectedTab == K["Guild Toasts"] then
		for _,_ in pairs(NAT) do
			number = number + 1
		end
	elseif selectedTab == K["Battle Net"] or selectedTab == K["Battle Net Toasts"] then
		number = BNGetNumFriends()
	elseif selectedTab == K["Alert Filters"] then
		number = #AF
	end
	if number <= HighestButton then
		return
	end
	SliderMW(me.slider, -delta)
end)

me.ListButtons2={}
for x = 1, HighestButton do
	me.ListButtons2[x] = NewButton( me, "RED")
	me.ListButtons2[x]:SetPoint("TOPLEFT",me.ListButtons[x] , "TOPRIGHT", 40, 0 )
	me.ListButtons2[x]:SetSize( width , 20)
	me.ListButtons2[x]:SetText( " " )
	me.ListButtons2[x].count = x
	me.ListButtons2[x]:SetScript("OnClick", function(self, button, down)
		if (button ~= "LeftButton") then
			return
		end
		if self.val == "" then return end
		PlaySound( "GAMEGENERICBUTTONPRESS" )
		if selectedTab == K["Guild Toasts"] then
			NickAlert.ListToggle("GToasts", self.val)
		else
			me.EBox:SetText(self.val)
		end
		NickAlert.ListDisplayUpdate()
		return
	end)
end

me.slider2 = CreateFrame( "Slider", "NAlertNNListSlider2", me, "OptionsSliderTemplate" )
me.slider2:SetMinMaxValues( 0, 1 )
me.slider2:SetOrientation("VERTICAL")
me.slider2:SetPoint("TOPLEFT", me.ListButtons2[1] ,"TOPRIGHT", 5 , 0)
me.slider2:SetPoint("BOTTOMLEFT", me.ListButtons2[HighestButton] ,"BOTTOMRIGHT", 5 , 0)
me.slider2:SetValueStep( 1 )
me.slider2:SetWidth( 16 )	
me.slider2:SetScript( "OnValueChanged", function( self )
	NickAlert.ListDisplayUpdate()
end)
getglobal(me.slider2:GetName() .. 'Low'):SetText( " " )
getglobal(me.slider2:GetName() .. 'High'):SetText( " " )
me.slider2:SetScript("OnMouseWheel", function(self, delta)
	local number = 0
	if selectedGuild ==  (GetGuildInfo("player")) then
		number = GetNumGuildMembers()
	else
		for _,_ in pairs(NAT[selectedGuild]) do
			number = number + 1
		end
	end
	if number <= HighestButton then
		return
	end
	SliderMW(self, -delta)
end)
SliderFrame2 = CreateFrame( "Frame", "NAlertSliderFrame2", me )
SliderFrame2:SetPoint("TOPLEFT", me.ListButtons2[1], "TOPLEFT", -10, 10)
SliderFrame2:SetPoint("BOTTOMRIGHT", me.slider2, "BOTTOMRIGHT", 10, -10)
SliderFrame2:EnableMouseWheel(1)
SliderFrame2:SetScript("OnMouseWheel", function(self, delta)
	local number = 0
	if selectedGuild ==  (GetGuildInfo("player")) then
		number = GetNumGuildMembers()
	else
		for _,_ in pairs(NAT[selectedGuild]) do
			number = number + 1
		end
	end
	if number <= HighestButton then
		return
	end
	SliderMW(me.slider2, -delta)
end)

me.EBox = CreateFrame( "EditBox", "NAlertNNEditbox", me, "InputBoxTemplate" )
me.EBox:SetFontObject("ChatFontNormal")
me.EBox:SetTextInsets(0, 0, 3, 3)
me.EBox:SetPoint("BOTTOMLEFT", me , "BOTTOMLEFT", 30 , 50 )
me.EBox:SetPoint("RIGHT", -32, 0)
me.EBox:SetHeight(19)
me.EBox:SetWidth(50)
me.EBox:SetAutoFocus(false)
me.EBox:SetMaxLetters( 254 )
me.EBox:SetScript("OnEnterPressed" , function(self)
	self:ClearFocus()
end)
me.EBox:SetScript("OnEscapePressed", function(self)
	self:SetText( "" )
	self:ClearFocus()
end)

me.EBox.Text = me:CreateFontString( nil, "ARTWORK", "GameFontHighlightSmall" )
me.EBox.Text:SetPoint( "BOTTOMLEFT", me.EBox , "BOTTOMLEFT", 0 , Y/4 )
me.EBox.Text:SetPoint( "RIGHT", -32, 0 )
me.EBox.Text:SetHeight( 32 )
me.EBox.Text:SetJustifyH( "LEFT" )
me.EBox.Text:SetJustifyV( "MIDDLE" )
me.EBox.Text:SetText( "Enter data or click a button above" )

me.AddButton = CreateFrame("Button", "NalertAddButton", me, "UIPanelButtonTemplate" )
me.AddButton:SetPoint("BOTTOMLEFT", me, "BOTTOMLEFT", 20 , 20 )
me.AddButton:SetSize( 150, 25)
me.AddButton:SetText("Add")
me.AddButton:SetScript("OnClick", function(self, button, down)
	if (button ~= "LeftButton") then
		return
	end
	if selectedTab == K["Guild Toasts"] then --Guild List
		if selectedGuild == GetGuildInfo("player") then
			StaticPopup_Show("NICKALERT_CANNOTDELETEGUILD")
		else
			StaticPopup_Show("NICKALERT_DELETEGUILD", selectedGuild)
		end
		NickAlert.ListDisplayUpdate()
		return
	end
	local EBoxText = me.EBox:GetText()
	if EBoxText == "" or EBoxText == " " then
		return
	end
	PlaySound( "GAMEGENERICBUTTONPRESS" )
	NickAlert.List( K[selectedTab + 100], "add", EBoxText )
	me.EBox:SetText("")
	me.EBox:ClearFocus()
	NickAlert.ListDisplayUpdate()
	return
end)

me.DeleteButton = CreateFrame("Button", "NAlertDeleteButton", me, "UIPanelButtonTemplate" )
me.DeleteButton:SetPoint("BOTTOMRIGHT", me, "BOTTOMRIGHT", -20 , 20 )
me.DeleteButton:SetSize( 150, 25)
me.DeleteButton:SetText("Delete")
me.DeleteButton:SetScript("OnClick", function(self, button, down)
	if (button ~= "LeftButton") then
		return
	end
	local EBoxText = me.EBox:GetText()
	if EBoxText == "" or EBoxText == " " then
		return
	end
	PlaySound( "GAMEGENERICBUTTONPRESS" )
	NickAlert.List( K[selectedTab + 100], "rem", EBoxText )
	me.EBox:SetText("")
	me.EBox:ClearFocus()
	NickAlert.ListDisplayUpdate()
	return
end)

me.refresh= function( self )
	me.slider:SetValue(0)
	me.slider2:SetValue(0)
	NickAlert.ListDisplayUpdate()
	me.init()
end


me.init = function(self)
	selectedGuild = GetGuildInfo("player")
	if not(PerChar) then
		PerChar = NickAlert_PerChar
	end
	if not(NAT) then
		NAT = NickAlert_Toasts
	end
	if not(NAT[selectedGuild]) then
		NAT[selectedGuild] = {}
	end
	local Gnum = GetNumGuildMembers()
	local friend
	local tmptable = {}
	for x = 1, Gnum do
		friend = (GetGuildRosterInfo(x))
		if not(NAT[selectedGuild][friend] ) then
			NAT[selectedGuild][friend] = false
		end
		tmptable[#tmptable +1] = friend
	end
	for index, _ in pairs( NAT[selectedGuild] ) do
		if not( tContains( tmptable, index )) then
			NAT[selectedGuild][index] = nil
		end
	end
	me.SelectButtonUpdate()
end


me.refresh = me.init

InterfaceOptions_AddCategory( me )

