local AddonName, NickAlert = ...

local NAS
local NAD
local NN
local CF
local WL
local PerChar
local NAT
local Triggers
local AF

-- Local text colors
local yel = "|cFFFFFF00"
local wht = "|cFFFFFFFF"
local blu = "|cFF00FFFF"
local red = "|cFFFF0000"
local grn = "|cFF00FF00"
local ltblu = "|cFF00CCFF"
local ltred = "|cFFFF6060"
local res = "|r"

-- Bill's Utils
local StatColor = BillsUtils.StatColor
local SJprint = BillsUtils.SJprint
local OptSaveTF = BillsUtils.OptSaveTF
local OptSaveVal = BillsUtils.OptSaveVal

BillsUtils.Locals[#BillsUtils.Locals +1] = function ()
	StatColor = BillsUtils.StatColor
	SJprint = BillsUtils.SJprint
	OptSaveTF = BillsUtils.OptSaveTF
	OptSaveVal = BillsUtils.OptSaveVal
end

NickAlert.SlashCommandsInit = function()
	NAS = NickAlert.Settings
	NAD = NickAlert.Defaults
	NN = NickAlert.NickNames
	CF = NickAlert.ChatFilter
	WL = NickAlert.WhisperList
	PerChar = NickAlert.PerChar
	NAT = NickAlert.ToastsList
	Triggers = NickAlert.Triggers
	AF = NickAlert.AlertFilters
end

-- ****************************************************************************
-- * Manage all the alert / filter lists
NickAlert.List = function( list, cmd, data )
	if type(cmd) == "string" then cmd = string.lower(cmd) end
	local StringTable
	local Table
	if list == "NickList" then
		Table = NN
		StringTable = { AddEntryError = " Nick Alert: nickname entry error \n \"/nalert add NAME\"",
						AddGood = " Nick Alert: nickname stored as NAME:",
						RemEntryError = " Nick Alert: nickname entry removal error \n \"/nalert rem NAME \" or \"/nalert rem # \"  from /nalert display",
						DisplayHeader = "Nickname List",
						DisplayFooter = "Nicknames stored on this server",
						HelpCmd = "/nanl cmd options",
						HelpAdd = "Adds a nickname to scan chats for and alert you if found",
						HelpRem = "Removes a stored nickname so it wont alert you anymore",
						HelpDisplay = "Displays a list of stored nicknames",
						TotalStored = "Nicknames stored for this server",
						EndHint = "\"/nanl cfg\" will open the GUI config for the nick list",
						}
	elseif list == "WhisperList" then
		Table = WL
		StringTable = { AddEntryError = " Nick Alert: Whisper List name entry error \n \"/nawl add NAME\"",
						AddGood = " Nick Alert: Whisper List name stored as NAME:",
						RemEntryError = " Nick Alert: Whisper List name entry error \n \"/nawl rem NAME \" or \"/nawl rem # \"  from /nawl display",
						DisplayHeader = "Whisper Alert List",
						DisplayFooter = "names stored for this server",
						HelpCmd = "/nawl cmd options",
						HelpAdd = "Adds a Name to alert you for when they whisper you \"/nawl add NAME\"",
						HelpRem = "Removes a Name from whisper alert list \"/nawl rem NAME\" or \"/nawl rem NUMBER\" (number from DISPLAY)",
						HelpDisplay = "Displays a list of saved names to you if they whisper you",
						TotalStored = "Characters stored for this server",
						EndHint = "\"/nawl cfg\" will open the GUI config for the whisper alert list",
						}
	elseif list == "Filter" then
		Table = CF
		StringTable = { AddEntryError = " Nick Alert: Filter entry error \n \"/nalert filter add CHANNEL\"   CHANNEL = Channel name or part of name (e.g. \"Trade\")",
						AddGood = " Nick Alert: Filter stored as:",
						RemEntryError = " Nick Alert: Filter list entry error \n \"/nalert filter rem FILTER \" or \"/nalert filter rem # \"  from /nalert filter display",
						DisplayHeader = "Filter List",
						DisplayFooter = "Filters stored on this account",
						HelpCmd = "/nalert filter cmd",
						HelpAdd = "Adds a channel to listen to \"/nalert filter add CHANNEL\"",
						HelpRem = "Removes a channel \"/nalert filter rem CHANNEL\" or \"/nalert filter rem NUMBER\" (number from DISPLAY)",
						HelpDisplay = "Displays a list of saved Channels to monitor if you are in them",
						TotalStored = "Chat Filters stored for this account",
						EndHint = "\"/nacf cfg\" will open the GUI config for the channel filter list",
						}
	elseif list == "Triggers" then
		Table = Triggers
		StringTable = { AddEntryError = " Nick Alert: trigger entry error \n \"/natrigger add TRIGGER\"",
						AddGood = " Nick Alert: trigger stored as TRIGGER:",
						RemEntryError = " Nick Alert: trigger entry error \n \"/natrigger rem NAME \" or \"/natrigger rem # \"  from /natrigger display",
						DisplayHeader = "Trigger List",
						DisplayFooter = "Triggers stored on this server",
						HelpCmd = "/natriggers cmd options",
						HelpAdd = "Adds a trigger to scan chats for and alert you if found",
						HelpRem = "Removes a stored trigger so it wont alert you anymore",
						HelpDisplay = "Displays a list of stored triggers",
						TotalStored = "Triggers stored for this account",
						EndHint = "\"/natrigger cfg\" will open the GUI config for the nick list",
						}
	elseif list == "AlertFilters" then
		Table = AF
		StringTable = { AddEntryError = " Nick Alert: Alert Filter entry error \n \"/naaf add ALERTFILTER\"",
						AddGood = " Nick Alert: Alert Filter stored as ALERTFILTER:",
						RemEntryError = " Nick Alert: Alert Filter entry removal error \n \"/naaf rem NAME \" or \"/naaf rem # \"  from /naaf display",
						DisplayHeader = "Alert Filters",
						DisplayFooter = "Alert Filters stored for this account",
						HelpCmd = "/naaf cmd options",
						HelpAdd = "Adds a filter to prevent alerts from triggering if they contain this",
						HelpRem = "Removes a stored Alert Filter so it wont prevent alerts anymore",
						HelpDisplay = "Displays a list of stored Alert Filters",
						TotalStored = "Alert Filters stored for this account",
						EndHint = "\"/naaf cfg\" will open the GUI config for the Alert Filter list",
						}
	else 
		return
	end
	
	if (cmd == "on" or cmd == "off") and list =="WhisperList" then 
		NAS[list] = cmd == "on"
		SJprint(yel, "Nick Alert:", blu, list, yel, "is", StatColor( NAS[list] ), res)
		return
	end

	if cmd == "add" then
		if type(data) == "nil" then
			SJprint( yel, StringTable.AddEntryError , res)
			return
		end
	
		if #Table > 0 then
			for x = 1, #Table do
				if Table[x] == data then
					set = true
					break
				end
			end
		end
	
		if not(set) then
			local index
			if #Table == nil then
				index = 1
			else
				index = #Table + 1
			end
			Table[index] = data
		end

		SJprint( yel, StringTable.AddGood, data , res)
		table.sort( Table )
		return
	end
	
	if cmd == "rem" then
		local rem = false
		local number = tonumber(data)
		local vtype = type(data)
		local numtype = type(number)
	
		if vtype == "nil" then
			SJprint( yel, StringTable.RemEntryError , res)
			return
		end

		if vtype == "string" and numtype == "nil" then
			if #Table > 0 then
				for x = 1, #Table do
					if Table[x] == data then
						table.remove(Table, x)
						rem = true
					end
				end
			end
		end

		if vtype == "number" or numtype == "number" then
			if number > 0 and number <= #Table then
				data = Table[number]
				table.remove(Table, number)
				rem = true
			end
		end
	
		if not(rem) then
			SJprint( yel, " Nick Alert: Error \n Unable to find ", data, " to remove from list", res)
		else
			SJprint( yel, " Nick Alert: ", data, " removed from list", res)
		end
		return
	end
	
	if cmd == "display" then
		SJprint( yel, "________________________________________", res)
		SJprint( yel, "Nick Alert", res)
		SJprint( yel, "  ", StringTable.DisplayHeader, res)
		SJprint( yel, "#  DATA:", res)
		if #Table > 0 then
			local Mod 
			for x = 1, #Table do
				Mod = math.fmod(x, 3)
				if Mod == 0 then
					SJprint( "|cFFFFFF00", x, "  ", Table[x], res)
				elseif Mod == 1 then
					SJprint( "|cFFFFCC00", x, "  ", Table[x], res)
				elseif Mod == 2 then
					SJprint( "|cFFFF9900", x, "  ", Table[x], res)
				end
			end
			SJprint( yel, #Table, StringTable.DisplayFooter , res)
		else
			SJprint( yel, "ERROR: No items stored", res)
		end
		return
	end
	
	SJprint( yel, "\n\n________________________________________", res)
	SJprint( yel, "Nick Alert:", res)
	if list == "WhisperList" then
		SJprint(yel, "Nick Alert:", blu, list, yel, "is", StatColor( NAS[list] ), res)
	end
	SJprint( blu, "  ", StringTable.HelpCmd , res)
	SJprint( blu, "     add", yel, StringTable.HelpAdd, res)
	SJprint( blu, "     rem", yel, StringTable.HelpRem, res)
	SJprint( blu, "     display", yel, StringTable.HelpDisplay , res)
	SJprint( "\n", yel, tostring(#Table), StringTable.TotalStored, res)
	SJprint( yel, StringTable.EndHint, res )
end

NickAlert.SettingsUpdate = function()
	NickAlert.MF:SetFont( STANDARD_TEXT_FONT, NAS.FontSize, "OUTLINE")
	NickAlert.MF:SetTimeVisible( NAS.FadeDelay )
	if NAS.MFAutoScale then
		local UIScale = UIParent:GetScale()
		NAS.MFScale =  math.floor((1/UIScale)*100)
	end
	NickAlert.MF:SetScale(NAS.MFScale / 100 )
	NickAlert.LogFrame:SetScale(NAS.MFScale / 100 )
	NickAlert.ScrollingMessageFrame:SetFont(STANDARD_TEXT_FONT, NAS.FontSize)
	if NAS.HideHandledToasts and NAS.Toasts then
		_G["BNToastFrame"]:UnregisterEvent( "BN_FRIEND_ACCOUNT_ONLINE" )
		_G["BNToastFrame"]:UnregisterEvent( "BN_FRIEND_ACCOUNT_OFFLINE" )
	elseif ( not(NAS.Toasts) or not(NAS.HideHandledToasts) ) and GetCVarBool("showToastWindow") then
		_G["BNToastFrame"]:RegisterEvent( "BN_FRIEND_ACCOUNT_ONLINE" )
		_G["BNToastFrame"]:RegisterEvent( "BN_FRIEND_ACCOUNT_OFFLINE" )
	end
end

NickAlert.CmdLine = function( msg )
	local cmd, arg, arg2 = string.split(" ", msg, 3)
	cmd = string.lower(cmd)
	
	if cmd == "config" or cmd == "cfg" then
		InterfaceOptionsFrame_OpenToCategory( NickAlert.panel )
		return
	end

	if not(NAS.Enable) and cmd ~= "enable" then
		SJprint( yel, "Nick Alert: The addon is disabled type \"", blu, "/nalert enable on", yel, "to enable", res)
		return
	end
	
	do -- on / off commands
		local K = {	enable = "Enable",				autoadd = "AutoAdd",
					toasts = "Toasts",				tfriends = "TFriends",
					tguild = "TGuild",				tbnet = "TBNet",
					guild = "Guild",				party = "Party",
					say = "Say",					bgs = "BGs",
					raid = "Raid",					yell = "Yell",
					emotes = "Emotes",				chats = "Chats",
					allwhispers = "AllWhispers",	allfriends = "AllFriends",
					allguild = "AllGuild",			allbnet = "AllBNet",
					whisperlist = "WhisperList",	bnet = "BNet",
					chatdebug = "ChatDebug",		custommp3 = "CustomMP3",
					customogg = "CustomOGG",		throttle = "Throttle",
					displaymode = "DisplayMode",	msbt = "MSBT",
					sound = "Sound",				mfwarn = "MFWarn",
					mfautoscale = "MFAutoScale",	logshow = "LogShow",
					screenflash = "ScreenFlash",	raidicons = "RaidIcons",
					hidehandledtoasts = "HideHandledToasts",
					}

		if K[cmd] then
			local VarName = K[cmd]
			OptSaveTF( NAS, VarName, arg)
			SJprint( yel, "Nick Alert:", VarName,"is", StatColor( NAS[VarName] ), res)
			NickAlert.SettingsUpdate()
			return
		end
	end
	
	do -- value range commands
	--              command					  VarName			       Min          Max          StatColor
		local K = { mfscale = 1,		[1] = "MFScale",		[101] = 50,	[201] = 300, [301] = false,
					fontsize = 2,		[2] = "FontSize",		[102] =  7, [202] =  24, [302] = false,
					fadedelay = 3,		[3] = "FadeDelay", 		[103] =  1, [203] =  60, [303] = true,
					throttletime = 4,	[4] = "ThrottleTime",	[104] =  1, [204] =  60, [304] = true,
					throttleamount = 5,	[5] = "ThrottleAmount",	[105] =  1, [205] =  60, [305] = true,
				}
		
		if K[cmd] then
			local index = K[cmd]
			local VarName, Min, Max, AutoColor = K[index], K[index + 100], K[index + 200], K[index + 300]
			arg = tonumber(arg)
			
			if cmd == "mfscale" and arg and NAS.MFScale ~= arg then
				NickAlert.CmdLine("mfautoscale off")
			end
			
			OptSaveVal( NAS, VarName, arg, Min, Max )
			NickAlert.SettingsUpdate()
			if AutoColor then
				SJprint( yel, "Nick Alert:", K[index],"is", StatColor( NAS[K[index]] ), res)
			else
				SJprint( yel, "Nick Alert:", K[index],"is", grn, NAS[K[index]], res)
			end
			return
		end
	end
	
	do -- list management commands
	local list, toggle = 1, 2
	
	--              command                        type             list                    desc
		local K = {	["nicklist"] = 1,		[ 1] = list,	[101] = "NickList",		[201] = "nickname", 
					["triggers"] = 2,		[ 2] = list,	[102] = "Triggers",		[202] = "trigger",
					["trigger"] = 2,
					["alertfilters"] = 3,	[ 3] = list,	[103] = "AlertFilters",	[203] = "Alert Filters",
					["alertfilter"] = 3,
					["filter"] = 4,			[ 4] = list,	[104] = "Filter",		[204] = "channel filter",
					["whisperlist"] = 5,	[ 5] = list,	[105] = "WhisperList",	[205] = "whisper alert",
					["bnet"] = 6,			[ 6] = toggle,	[106] = "BNet",			[206] = "Battle-Net message alert",
					["tfriends"] = 7,		[ 7] = toggle,	[107] = "TFriends",		[207] = "friend toast",
					["tguild"] = 8,			[ 8] = toggle,	[108] = "TGuild",		[208] = "guild toast",
					["tbnet"] = 9,			[ 9] = toggle,	[109] = "TBnet",		[209] = "Battle-Net toast",
				}
		
		if K[cmd] then
			local index = K[cmd]
			if arg == "cfg" or arg == "config" then
				InterfaceOptionsFrame_OpenToCategory( NickAlert.panel3 )
				NickAlert.panel3.SelectButton[index]:Click("LeftButton")
				return
			end
			if K[index] == list then
				NickAlert.List( K[index + 100], arg, arg2)
			elseif K[index] == toggle then
				OptSaveTF( NAS, K[index + 100], arg)
				SJprint( yel, "Nick Alert:", blu, K[index + 100], wht, "is", StatColor( NAS[K[index + 100]] ), res)
			end
			
			SJprint(yel, "Type: ", blu, "/na "..cmd.." cfg", wht, "to manage the "..K[index + 200].." list", res)
			return
		end
	end
	
	if cmd == "toastmode" then
		if arg == "online" then
			NAS.ToastMode = "Online"
		elseif arg == "offline" then
			NAS.ToastMode = "Offline"
		elseif arg == "both" then
			NAS.ToastMode = "Both"
		else
			SJprint( yel, "Nick Alert:", res)
			SJprint( blu, "  /nalert toastmode", res)
			SJprint( red, arg, yel, "is not a valid command", res)
		end
		SJprint( yel, "Nick Alert:", blu, "ToastMode", wht, "is",grn, NAS.ToastMode , res)
		return
	end
	
	-- Log Window commands
	if cmd == "log" then
		if arg == "show" then
			NickAlert.LogShown = true
			NickAlert.LogFrame:Show()
		elseif arg == "hide" then
			NickAlert.LogShown = false
			NickAlert.LogFrame:Hide()
		elseif arg == "clear" then
			NickAlert.ScrollingMessageFrame:Clear()
		else
			OptSaveTF( NAS, "Log", arg)
			SJprint( yel, "Nick Alert:", blu, "Log", wht, "is", StatColor( NAS.Log ), res)
		end
		return
	end
	
	-- Message Frame commands		
	if cmd == "mf" then
		if arg == "unlock" then
			NickAlert.MsgFrameUnlock()
		elseif arg == "lock" then
			NickAlert.MsgFrameLock()
		elseif arg == "scale" then
			NickAlert.CmdLine("mfscale ".. (arg2 and arg2 or " "))
		elseif arg == "autoscale" then
			NickAlert.CmdLine("mfautoscale ".. ( arg2 and arg2 or " "))
		else
			OptSaveTF( NAS, "MF", arg)
			SJprint( yel, "Nick Alert:", blu, "MF", wht, "is", StatColor( NAS.MF ), res)
		end
		return
	end
	
	SJprint( yel, "________________________________________", res)
	if cmd ~= "" then
		SJprint( yel, "Nick Alert:", res)
		SJprint( blu, "  /nalert cmd", res)
		SJprint( red, cmd, yel, "is not a valid command", res)
	end
	SJprint( yel, "  Commands are:", blu, "BLUE", res)
	SJprint( yel, "  Addon State:", res)
	SJprint( blu, "     Enable", yel, "Turns Nick Alert on and off ", StatColor( NAS.Enable ,true), res)
	SJprint( blu, "     AutoAdd", yel, "Add your char names to list automatically", StatColor( NAS.AutoAdd , true), res)
	SJprint( yel, "  Toast Settings:", res)
	SJprint( blu, "     Toasts", yel, "Alert you when people go online/offline (Must be ON for any toast alerts)", StatColor( NAS.Toasts, true), res)
	SJprint( blu, "     ToastMode", yel, "Select online/offline/both for the toasts you want", grn, NAS.ToastMode, res)
	SJprint( blu, "     TFriends", yel, "All Friends online/offline toasts [on] or just marked [off]   to edit list[cfg]", StatColor( NAS.TFriends, true ), res)
	SJprint( blu, "     TGuild", yel, "All Guild online/offline toasts [on] or just marked [OFF]   to edit list[cfg]", StatColor( NAS.TGuild, true ), res)
	SJprint( blu, "     TBNet", yel, "All Real-ID/Battle-Tag online/offline toasts [on] or just marked [OFF]   to edit list[cfg]",StatColor( NAS.TBNet, true ), res)
	SJprint( yel, "  Nick / Trigger Scanning:", res)
	SJprint( blu, "     Guild", yel, "Enable scanning of guild channels", StatColor( NAS.Guild, true ), res)
	SJprint( blu, "     Party", yel, "Enable scanning of party channel", StatColor( NAS.Party, true ), res)
	SJprint( blu, "     Say", yel, "Enable scanning of say channel", StatColor( NAS.Say, true ), res)
	SJprint( blu, "     BGs", yel, "Enable scanning of BattleGround channel", StatColor( NAS.BGs, true ), res)
	SJprint( blu, "     Raid", yel, "Enable scanning of Raid channels", StatColor( NAS.Raid, true ), res)
	SJprint( blu, "     Yell", yel, "Enable scanning of Yells", StatColor( NAS.Yell, true ), res)
	SJprint( blu, "     Emotes", yel, "Enable scanning of Emotes", StatColor( NAS.Emotes, true ), res)
	SJprint( blu, "     Chats", yel, "Enable scanning of general chat channels", StatColor( NAS.Chats, true ), yel, "must me individually enabled in channel list", res)
	SJprint( blu, "     NickList", yel, "Manages nicknames for above alert types [submenu available]   to edit list[cfg]", res)
	SJprint( blu, "     Triggers", yel, "Manages trigger list for above scanning [submenu available]   to edit list[cfg]", res)
	SJprint( yel, "  Message Alerts:", res)	
	SJprint( blu, "     WhisperList", yel, "Enable alerts for whispers from specified people", StatColor( NAS.WhisperList, true), yel, "[submenu available]   to edit list[cfg]", res)
	SJprint( blu, "     AllWhispers", yel, "Trigger alert on all received non BNet whispers", StatColor( NAS.AllWhispers, true), res)
	SJprint( blu, "     AllFriends", yel, "Trigger alert on whispers from friends", StatColor( NAS.AllFriends, true), res)
	SJprint( blu, "     AllGuild", yel, "Trigger alert on whispers from any guild member", StatColor( NAS.AllGuild, true),res)
	SJprint( blu, "     AllBNet", yel, "Trigger alert on all Battle-Net messages", StatColor( NAS.AllBNet, true), res)
	SJprint( blu, "     BNet", yel, "Enable alerts for messages from specified Real IDs   to edit list[cfg]", StatColor( NAS.BNet, true), res)
	SJprint( yel, "  Output Settings:", res)
	SJprint( blu, "     Filter", yel, "Filter is a WHITELIST that filters all \"/1 /2 /3 ...\" channels not in the list [submenu available]   to edit list[cfg]", res)
	SJprint( blu, "     AlertFilter", yel, "Alert Filter is a BLACKLIST that filters ALL alerts containing the filter text[submenu available]   to edit list[cfg]", res)
	SJprint( blu, "     ChatDebug", yel, "Enable verbose output on what the addon is doing", StatColor( NAS.ChatDebug, true), res)
	SJprint( blu, "     DisplayMode", yel, "Display mode of trigger (ie Party, Guild, BNet)",StatColor( NAS.DisplayMode, true), res)
	SJprint( blu, "     MF", yel, "Enables output to the moveable Message Frame", StatColor( NAS.MF, true, "lock", "unlock" ), res)
	SJprint( blu, "     MFWarn", yel, "Warns when the message frame is left unlocked and displayed", StatColor( NAS.MFWarn, true), res)
	SJprint( blu, "     MFAutoScale", yel, "Enables the message frame to auto scale to 1 (+/-) (or set the scale below)", StatColor( NAS.MFAutoScale, true), res)
	SJprint( blu, "     MFScale", yel, "Percent scale the size of the message frame [50 - 300]", grn, NAS.MFScale, res)
	SJprint( blu, "     FontSize", yel, "The size of the font in the message frame [7 - 24]", grn, NAS.FontSize, res)
	SJprint( blu, "     FadeDelay", yel, "How long before the text in the message frame fades [1-60 secs]", grn, NAS.FadeDelay, res)
	SJprint( blu, "     Log", yel, "Put alerts into the log window", StatColor( NAS.Log, true, "show", "hide", "clear"), res)
	SJprint( blu, "     LogShow", yel, "Show the log when you log in", StatColor( NAS.LogShow, true), res)
	SJprint( blu, "     ScreenFlash", yel, "Flash the edges of the screen when you get an alert", StatColor( NAS.ScreenFlash, true), res)
	SJprint( blu, "     RaidIcons", yel, "Process the {rt#} into the raid icon graphic", StatColor( NAS.RaidIcons, true), res)
	SJprint( blu, "     MSBT", yel, "Enable output to MikScrollingBattleText if installed", StatColor( NAS.MSBT, true), res)
	SJprint( blu, "     Sound", yel, "Enable sound when a nick match is found", StatColor(NAS.Sound, true), res)
	SJprint( blu, "     CustomMP3", yel, "Enable custom alert.mp3 sound when a nick match is found", StatColor( NAS.CustomMP3, true), res)
	SJprint( blu, "     CustomOGG", yel, "Enable custom alert.ogg sound when a nick match is found", StatColor( NAS.CustomOGG, true), res)
	SJprint( blu, "     Throttle", yel, "Enable alert throttle to stop people from noise spamming you", StatColor( NAS.Throttle, true), res)
	SJprint( blu, "     ThrottleTime", yel, "Amount of time to count alerts for [1-60 secs]", grn, NAS.ThrottleTime, res)
	SJprint( blu, "     ThrottleAmount", yel, "Max number of alerts in above time frame [1-60]", grn, NAS.ThrottleAmount, res)
	SJprint( blu, "     HideHandledToasts", yel, "Don't show toasts in default WoW toast frame if the addon handled them", StatColor( NAS.HideHandledToasts, true), res)
	print(" ")
	SJprint("     ", yel, #NN, "nicknames are stored for this server.")
	SJprint("     ", yel, #Triggers, "triggers are stored for this account")
	SJprint("     ", yel, #WL, "whisper alerts are stored for this server.")
	SJprint("     ", yel, #CF, "Chat Filters are stored for this account.")
	SJprint("     ", yel, #AF, "Alert Filters are stored for this account.")
	print(" ")
	SJprint( blu, "     /nanl", yel, "manage the nick alert list", res)
	SJprint( blu, "     /natl", yel, "manage the trigger list", res)
	SJprint( blu, "     /naaf", yel, "manage the Alert Filter list", res)
	SJprint( blu, "     /nawl", yel, "manage the whisper list", res)
	SJprint( blu, "     /nabn", yel, "manage the Real ID list", res)
	SJprint( blu, "     /nacf", yel, "manage the channel filter list", res)
	SJprint( blu, "     /namf", yel, "message frame [on/off/lock/unlock/scale]", res)
	return
end

-- Standard Command Line
SLASH_NALERT1 = "/nalert"
SLASH_NALERT2 = "/nickalert"
SLASH_NALERT3 = "/na"
SlashCmdList["NALERT"] = function(msg)
	NickAlert.CmdLine(msg)
end

SLASH_NALOG1 = "/nal"
SlashCmdList["NALOG"] = function(msg)
	NickAlert.CmdLine( "log "..msg)
end

-- Nick Alert Trigger List
SLASH_NATRIGGER1 = "/natrigger"
SLASH_NATRIGGER2 = "/natl"
SlashCmdList["NATRIGGER"] = function(msg)
	NickAlert.CmdLine("triggers "..msg)
end

-- Nick Alert Nick List
SLASH_NANL1 = "/nanl"
SlashCmdList["NANL"] = function(msg)
	NickAlert.CmdLine("nicklist "..msg)
end

-- Nick Alert Whisper List
SLASH_NAWL1 = "/nawl"
SlashCmdList["NAWL"] = function(msg)
	NickAlert.CmdLine("whisperlist "..msg)
end

-- Nick Alert Chat Filter
SLASH_NACF1 = "/nacf"
SlashCmdList["NACF"] = function(msg)
	NickAlert.CmdLine("filter "..msg)
end

-- Nick Alert Alert Filter
SLASH_NACF1 = "/naaf"
SlashCmdList["NAAF"] = function(msg)
	NickAlert.CmdLine("alertfilter "..msg)
end

-- Nick Alert Battle Net
SLASH_NABN1 = "/nabn"
SlashCmdList["NABN"] = function(msg)
	NickAlert.CmdLine("bnet "..msg)
end

-- Nick Alert Message Frame
SLASH_NAMF1 = "/namf"
SlashCmdList["NAMF"] = function(msg)
	NickAlert.CmdLine("mf "..msg)
end

